@@ -735,6 +735,38 @@ func TestConnCollection_newConn(t *testing.T) {
 			false,
 			false,
 		},
+		{
+			"+named",
+			expect{true, true},
+			fields{
+				keepAlive:  4,
+				dsn:        "pigeon://aaaa:bbbb@uri/InstanceName?app+name=Zabbix+agent+2+MSSQL+plugin&keepAlive=4",
+				driverName: "testdriver",
+			},
+			args{&connConfig{
+				User:     "aaaa",
+				Password: "bbbb",
+				URI:      "pigeon://uri/InstanceName",
+			}},
+			false,
+			false,
+		},
+		{
+			"+namedWithPort",
+			expect{true, true},
+			fields{
+				keepAlive:  4,
+				dsn:        "pigeon://aaaa:bbbb@uri:1435/InstanceName?app+name=Zabbix+agent+2+MSSQL+plugin&keepAlive=4",
+				driverName: "testdriver",
+			},
+			args{&connConfig{
+				User:     "aaaa",
+				Password: "bbbb",
+				URI:      "pigeon://uri:1435/InstanceName",
+			}},
+			false,
+			false,
+		},
 		{
 			"+validWithTLS",
 			expect{true, true},
@@ -743,7 +775,7 @@ func TestConnCollection_newConn(t *testing.T) {
 				dsn: "pigeon://aaaa:bbbb@uri:1433?" +
 					"TrustServerCertificate=false&" +
 					"app+name=Zabbix+agent+2+MSSQL+plugin&" +
-					"certificate=%2Fa%2Fb%2Fc&" +
+					"certificate=abc&" +
 					"encrypt=true&" +
 					"hostNameInCertificate=server&" +
 					"keepAlive=4&" +
@@ -754,7 +786,7 @@ func TestConnCollection_newConn(t *testing.T) {
 				User:                   "aaaa",
 				Password:               "bbbb",
 				URI:                    "pigeon://uri",
-				CACertPath:             "/a/b/c",
+				CACertPath:             "abc",
 				TrustServerCertificate: "false",
 				HostNameInCertificate:  "server",
 				Encrypt:                "true",
