@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright 2001-2024 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** Licensed under the Apache License, Version 2.0 (the "License");
 ** you may not use this file except in compliance with the License.
@@ -27,14 +27,14 @@ import (
 	"testing"
 	"time"
 
-	"git.zabbix.com/ap/mssql/plugin/dbconn"
-	"git.zabbix.com/ap/mssql/plugin/handlers"
-	"git.zabbix.com/ap/mssql/plugin/params"
-	"git.zabbix.com/ap/plugin-support/log"
-	"git.zabbix.com/ap/plugin-support/metric"
-	"git.zabbix.com/ap/plugin-support/plugin"
 	"github.com/google/go-cmp/cmp"
 	"github.com/google/go-cmp/cmp/cmpopts"
+	"golang.zabbix.com/plugin/mssql/plugin/dbconn"
+	"golang.zabbix.com/plugin/mssql/plugin/handlers"
+	"golang.zabbix.com/plugin/mssql/plugin/params"
+	"golang.zabbix.com/sdk/log"
+	"golang.zabbix.com/sdk/metric"
+	"golang.zabbix.com/sdk/plugin"
 )
 
 //nolint:paralleltest,tparallel
@@ -76,7 +76,6 @@ func Test_mssqlPlugin_Start(t *testing.T) {
 		},
 	}
 	for _, tt := range tests {
-		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
 
@@ -122,7 +121,6 @@ func Test_mssqlPlugin_Stop(t *testing.T) {
 		{"+valid", fields{conns: &dbconn.ConnCollection{}}},
 	}
 	for _, tt := range tests {
-		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
 
@@ -298,7 +296,6 @@ func Test_mssqlPlugin_Export(t *testing.T) {
 		},
 	}
 	for _, tt := range tests {
-		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
 
@@ -339,7 +336,6 @@ func Test_mssqlPlugin_registerMetrics(t *testing.T) {
 		},
 	}
 	for _, tt := range tests {
-		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
 
